Closed (fixed)
Project:
Drupal core
Version:
11.3.x-dev
Component:
phpunit
Priority:
Normal
Category:
Bug report
Assigned:
Unassigned
Issue tags:
Reporter:
Created:
17 Oct 2025 at 11:50 UTC
Updated:
18 Nov 2025 at 12:39 UTC
Jump to comment: Most recent
Comments
Comment #3
berdirComment #4
smustgrave commentedSo I'm sure these fluctuate but compared this run to the last run from HEAD
Javascript #1 3 min 27 sec compared to 3 min 41 sec
Javascript #2 3 min 7 sec compared to 5 min 12 sec
Javascript #3 3 min 34 sec compared to 2 min 53 sec
So definitely improvement in 2/3 of the runs. The #3 may have been an outlier since there's such a difference in #2
Going to mark as a net improvement.
Comment #5
berdirThis shouldn't result in a measurable difference *under normal circumstances*. At most it would maybe be a second here and there if we don't have to wait another second. But if your browser is somehow acting up like mine does then it makes a huge difference and it's ~30s faster per profiled request.
Comment #9
catchCommitted/pushed to 11.x and cherry-picked to 11.3.x, thanks!